@@ -514,8 +514,11 @@ sub generate_minil_toml {
 
     my $fname        = File::Spec->catfile($self->dir, 'minil.toml');
     my $project_name = $self->_detect_project_name_from_dir;
-    my $content      = qq{name = "$project_name"};
-    spew_raw($fname, $content);
+    my $content      = join("\n",
+        qq{name = "$project_name"},
+        qq{# badges = ["travis"]},
+    );
+    spew_raw($fname, $content . "\n");
 }
 
 sub regenerate_readme_md {
@@ -559,7 +562,7 @@ sub regenerate_readme_md {
 }
 
 sub verify_prereqs {
-    my ($self, $phases, $type) = @_;
+    my ($self) = @_;
 
     if ($Minilla::AUTO_INSTALL) {
         system('cpanm', '--quiet', '--installdeps', '--with-develop', '.');
